@@ -1,7 +1,7 @@
 from terminal import red, blue, bold, magenta, white
 from .externals.command import Command
 
-from . import const,i18n_util,cli_project,cli_oss
+from . import const,i18n_util,cli_project,cli_oss,cli_qsub
 from .action import login, config, info, cluster,events, job, cluster_create, cluster_delete, cluster_update, instance_type \
     , job_delete, job_restart, job_stop, job_update, job_create, log_fetch, job_submit,checker\
     ,image,image_create,image_delete,disk_type,resource_type
@@ -76,6 +76,7 @@ class Cli:
         cmd_config.option('-l,--locale [locale]', MSG['config']['option']['locale'])
         cmd_config.option('-i,--image [imageId]', MSG['config']['option']['image'])
         cmd_config.option('-t,--type [instanceType]', MSG['config']['option']['type'])
+        #cmd_config.option('-c,--cluster [clusterId]', MSG['config']['option']['cluster'])
         cmd_config.option('-s,--ssl [ssl]', MSG['config']['option']['ssl'], visible=IS_GOD)
         cmd_config.option('-v,--version [version]', MSG['config']['option']['version'], visible=IS_GOD)
         cmd_config.option('-g,--god [god]', MSG['config']['option']['god'], visible=IS_GOD)
@@ -245,6 +246,7 @@ class Cli:
         cmd_log.option('-d, --dir_path [dir_path]', MSG['log']['option']['dir_path'])
         cmd_log.option('-e, --stderr', MSG['log']['option']['stderr'])
         cmd_log.option('-o, --stdout', MSG['log']['option']['stdout'])
+        cmd_log.option('-m, --log_mapping', MSG['log']['option']['log_mapping'])
         self.program.action(cmd_log)
 
         ##################################################
@@ -325,6 +327,10 @@ class Cli:
         cmd_create_cluster.option("--resource_type [resource_type]",
                                   MSG['create_cluster']['option']['resource_type'])
 
+        cmd_create_cluster.option("--spot_price_limit [spot_price_limit]",
+                                  MSG['create_cluster']['option']['spot_price_limit'])
+
+
         cmd_create_cluster.option("-m, --mount [kv_pairs]", '(%s) %s' % (red(MSG['changed']),MSG['create_cluster']['option']['mount']),
                                   resolve=cluster_create.trans_mount)
         cmd_create_cluster.option("--nas_access_group [nas_access_group]",
@@ -385,6 +391,8 @@ class Cli:
                                   resolve=cluster_update.trans_user_data)
         cmd_update_cluster.option("-e, --env [kv_pairs]", MSG['update_cluster']['option']['env'],
                                   resolve=cluster_update.trans_env)
+        cmd_update_cluster.option("--spot_price_limit [spot_price_limit]",
+                                  MSG['update_cluster']['option']['spot_price_limit'])
         cmd_update_cluster.option("--show_json",
                                   MSG['update_cluster']['option']['show_json'])
         self.program.action(cmd_update_cluster)
@@ -553,6 +561,10 @@ class Cli:
 
         cmd_submit_job.option("--resource_type [resource_type]",
                                   MSG['submit']['option']['resource_type'])
+        cmd_submit_job.option("--spot_price_limit [spot_price_limit]",
+                              MSG['submit']['option']['spot_price_limit'])
+
+
         cmd_submit_job.option("--disk [disk_configs]",
                                   MSG['submit']['option']['disk'],
                                   resolve=job_submit.trans_disk)
@@ -575,6 +587,14 @@ class Cli:
                               MSG['submit']['option']['show_dag'])
         self.program.action(cmd_submit_job)
 
+        ##############################################
+
+        ##############################################
+
+        # qsub
+        cmd_qsub = cli_qsub.createCommand()
+        self.program.action(cmd_qsub)
+
 
         # check debug
         cmd_check = Command('check', alias=['ch'],
