@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 from ..const import CMD
+from terminal import magenta
 
 IMG_ID = 'img-ubuntu'
 INS_TYPE = 'ecs.s3.large'
@@ -22,6 +23,7 @@ def getJSON():
                 "locale": 'set locale, scope:[zh_CN|en]',
                 "image": "set default image Id, type '%s i' for more image" % CMD,
                 "type": "set default InstanceType, type '%s t' for more instanceType" % (CMD),
+                'cluster': '''set default cluster, type '%s c' for more clsuter.''' % (CMD),
                 'version': "set version for stg environment, example: 2015-10-01",
                 "god": "use god mode, scope:[true|false]",
                 'ssl': 'requesting with https, scope:[true|false]'
@@ -72,7 +74,8 @@ def getJSON():
             'option': {
                 'dir_path': 'directory path to save logs, if your don\'t set this option, just print logs',
                 'stderr': 'show stderr log only',
-                'stdout': 'show stdout log only'
+                'stdout': 'show stdout log only',
+                'log_mapping': 'show log_mapping logs only'
             }
         },
         'create_image': {
@@ -100,6 +103,7 @@ def getJSON():
                 'env': "optional,set environment variables, format: <k>:<v>[,<k2>:<v2>...]",
                 'user_data': "optional, user data k-v pairs, exp: a:b,c:e",
                 'resource_type': 'optional, default "OnDemand", scope: [OnDemand|Spot]',
+                'spot_price_limit': 'optional, it\'s available when resource_type is Spot(unit: yuan,works to three decimal places). Set to 0 means using the system automatically bid(But lower than the "OnDemand" price)',
                 'disk': """optional, mount system disk and a data disk(optional)Usage: "--disk system:default:40,data:cloud:50:/home/disk1".
                                              Default: system:default:40, mount 40GB default disk as system disk.
                                              System disk config format: system:<default|cloud|ephemeral...>:<40-500>,
@@ -141,6 +145,7 @@ def getJSON():
                 'nodes': "required, should be positive integer",
                 'env': "optional,set environment variables, format: <k>:<v>[,<k2>:<v2>...]",
                 'user_data': "optional, user data k-v pairs, exp: a:b,c:e",
+                'spot_price_limit': 'optional, it\'s available when resource_type is Spot(unit: yuan,works to three decimal places). Set to 0 means using the system automatically bid(But lower than the "OnDemand" price)',
                 'mount': """optional,mount a nas path to local file system in read/write mode, kv-pairs, multi-supported,
         format: <nas_path>:<dir_path>[,<nas_path2>:<dir_path2>...],
         example: nas://path/to/mount:/home/admin/dir.
@@ -242,6 +247,7 @@ def getJSON():
                 'nas_access_group': 'NAS access groups',
                 'nas_file_system': 'NAS file system',
                 'resource_type': 'optional, default "OnDemand", scope: [OnDemand|Spot]',
+                'spot_price_limit': 'optional, it\'s available when resource_type is Spot(unit: yuan,works to three decimal places). Set to 0 means using the system automatically bid(But lower than the "OnDemand" price)',
                 'reserve_on_fail': 'optional, won\'t release auto-cluster when job failed',
                 'no_cache_support': 'optional, cancel the cache for ossmounter',
                 'vpc_cidr_block': 'CIDR, such as: 192.168.0.0/16',
@@ -343,5 +349,39 @@ def getJSON():
                     'yes': 'delete in silent mode'
                  }
             }
+        },
+        'qsub': {
+            'description': '%sqsub supported. Now migrate you qsub command to BatchCompute is much easier than you think' % (magenta('(New)')),
+            'detail': 'qsub supported. Now migrate you qsub command to BatchCompute is much easier than you think',
+            'option': {
+                'd': '''Defines the working directory path to be used for the job. If the -d option is not specified,
+                                         the default working directory is the home directory. This option sets the environment variable PBS_O_INITDIR.
+                                         ''',
+                'e': '''Defines the path to be used for the standard error stream of the batch job.
+                                         For example: -e /home/logs/stderr.log
+                                         ''',
+                'j': '''Declares if the standard error stream of the job will be merged with the standard output stream of the job.
+                                         An option argument value of oe directs that the two streams will be merged, intermixed,
+                                         as standard output. An option argument value of eo directs that the two streams will be merged,
+                                         intermixed, as standard error.
+
+                                         If the join argument is n or the option is not specified, the two streams will be two separate files.
+                      ''',
+                'l': '''Defines the resources that are required by the job and establishes a limit to the amount of resource that can be consumed.
+                                         If not set for a generally available resource, such as CPU time, it will be set to default one in bcs.
+                                         The resource_list argument is of the form:
+                                         resource_name[=[value]][,resource_name[=[value]],...]
+                                         ''',
+                'N': 'Declares a name for the job. ',
+                'o': '''Defines the path to be used for the standard output stream of the batch job.'
+                                         For example: -e /home/logs/stdout.log
+                                         ''',
+                'q': '''Batch compute queues with automatic scheduling, no need to specify a queue,
+                                         but you can specify a cluster, such as:"-q @cls-xxxx",
+                                         if you specify a queue, like:"-q 118@cls-xxx", the string before @ will be ignore.''',
+                'V': '''Declares that all environment variables in the qsub command's environment are to be exported to the batch job.''',
+                'show_json': 'optional,just output a BatchCompute job descrition json, won\'t submit a job',
+                'show_opt': 'optional,just output an options json, won\'t submit a job',
+            }
         }
     }
