@@ -2,6 +2,7 @@
 from ..util import smart_unicode
 from ..const import STRING
 from ..const import CMD
+from terminal import magenta
 
 IMG_ID = 'img-ubuntu'
 INS_TYPE = 'ecs.s3.large'
@@ -40,6 +41,7 @@ def __get_json():
                 "locale": '设置语言地域, 可选范围:[zh_CN|en]',
                 "image": "设置默认镜像Id, 运行 '%s i' 可以列出可用的Image" % CMD,
                 "type": "设置默认InstanceType, 运行 '%s t' 可以看到本区域支持的instanceType" % (CMD),
+                "cluster": "设置默认集群, 运行 '%s c' 可以看到已经创建的集群" % (CMD),
                 'version': "设置版本, 支持预发环境使用,版本如: 2015-10-01",
                 'god': "使用上帝模式, 可选范围:[true|false]",
                 'ssl': '使用https访问BatchCompute, 可选范围:[true|false]'
@@ -90,7 +92,8 @@ def __get_json():
             'option': {
                 'dir_path': '指定本地目录用以保存oss日志, 如果没有指定,则显示日志到屏幕',
                 'stderr': '只显示stderr日志',
-                'stdout': '只显示stdout日志'
+                'stdout': '只显示stdout日志',
+                'log_mapping': '只显示log_mapping日志'
             }
         },
         'create_image': {
@@ -116,6 +119,7 @@ def __get_json():
                 'description': "可选, 描述信息, string",
                 'env': "可选,设置环境变量, 格式: <k>:<v>[,<k2>:<v2>...]",
                 'resource_type': '可选, 默认 "OnDemand(按需)", 可选范围:[OnDemand|Spot]',
+                'spot_price_limit': '可选, resource_type为Spot时有效(单位为元,可以为小数). 设置为0表示使用系统自动出价(但不会超过按量付费价格)',
                 'user_data': "可选, 用户数据, k:v 对,多个逗号隔开, 格式: k:v,k2:v2",
                 'disk': """可选, 挂载磁盘, 支持系统盘配置和一块数据盘(可选)的配置,
                                              使用方法如: "--disk system:default:40,data:cloud:50:/home/disk1".
@@ -156,6 +160,7 @@ def __get_json():
                 'yes': "可选, 不要询问直接修改",
                 'nodes': "必选, 期望修改的机器数, 必须为正整数",
                 'env': "可选,设置环境变量, 格式: <k>:<v>[,<k2>:<v2>...]",
+                'spot_price_limit': '可选, resource_type为Spot时有效(单位为元,可以为小数). 设置为0表示使用系统自动出价(但不会超过按量付费价格)',
                 'user_data': "可选, 用户数据, k:v 对,多个逗号隔开, 格式: k:v,k2:v2",
                 'mount': """可选,读写模式挂载NAS配置, 格式: <nas_path>:<dir_path>[,<nas_path2>:<dir_path2>...],
         如: nas://path/to/mount:/home/admin/nasdir 表示将NAS路径挂载到本地目录。
@@ -251,6 +256,7 @@ def __get_json():
                 'nas_access_group': 'NAS 权限组',
                 'nas_file_system': 'NAS 文件系统',
                 'resource_type': '可选, 默认 "OnDemand(按需)", 可选范围:[OnDemand|Spot]',
+                'spot_price_limit': '可选, resource_type为Spot时有效(单位为元,可以为小数). 设置为0表示使用系统自动出价(但不会超过按量付费价格)',
                 'reserve_on_fail': '可选, 作业失败不会释放autoCluster, 便于调查问题',
                 'no_cache_support': '可选, 取消OSSMounter缓存',
                 'vpc_cidr_block': 'IP网段,如: 192.168.0.0/16',
@@ -352,5 +358,25 @@ def __get_json():
                     'yes': '可选,直接删除无需询问'
                  }
             }
+        },
+        'qsub': {
+            #https://linux.die.net/man/1/qsub-torque
+            'description': '%s对qsub的兼容支持,可快速将qsub迁移至批量计算' % (magenta('(New) ')),
+            'detail': '''对qsub的兼容支持,可快速将qsub迁移至批量计算,部分不支持的option自动忽略。
+                      其他字段可以在用户目录下配置 ~/.qsub-task-description.json''',
+            'option': {
+                'd': '指定工作路径, 并添加到环境变量中, key 为 PBS_O_INITDIR.',
+                'e': '定义标准错误日志的路径. 如果不设置, 默认使用批量计算生成的路径.',
+                'j': '合并stderr日志到stdout, 可选:[oe|eo|n], 默认为:n,不合并',
+                'l': '''声明计算需要的资源, 不设置则使用默认的。
+                                         格式: resource_name[=[value]][,resource_name[=[value]],...]''',
+                'N': '声明作业名称',
+                'o': '定义标准输出日志的路径. 如果不设置, 默认使用批量计算生成的路径.',
+                'q': '''批量计算集群有自动调度的队列,无需也无法指定queue, 可以指定集群, 如:"-q @cls-xxxx",
+                                         如果指定了queue, 如:"-q 118@cls-xxx", @前面的字符串会被忽略。''',
+                'V': '''将当前qsub命令运行环境中的环境变量全部设置到job运行环境中。''',
+                'show_json': '只显示json不提交作业',
+                'show_opt': '只显示opt json不提交作业',
+            }
         }
     }
